@@ -29,10 +29,18 @@ class AccessSettings {
 public:
   std::vector<std::string> user_names_; //!< [U
   std::vector<std::string> user_password_; //!< pX[h
-  size_t user_index_;                //!< I𒆂̃[UCfbNX
-  std::string effect_decide_;        //!< 艹
-  std::string effect_type_;          //!< ^Cv
-  std::string effect_miss_;          //!< ~X^Cv
+
+  std::vector<int> convert_mode_; //!< ̓[h
+  std::vector<size_t> practice_num_;         //!< K
+
+  std::vector<int> music_volume_; //!< Ȃ̃{[
+  std::vector<int> effect_volume_; //!< ʉ̃{[
+
+  size_t user_index_;           //!< I𒆂̃[UCfbNX
+
+  std::string effect_decide_;   //!< 艹
+  std::string effect_type_;     //!< ^Cv
+  std::string effect_miss_;     //!< ~X^Cv
 
   AccessSettings(const char* savedir);
   ~AccessSettings(void);
