@@ -47,8 +47,8 @@ namespace beego {
 
     // !!! ĐhCu̎w
     // !!! CD ̗LmFH
-    // !!! gbN̎擾
-    // !!! gbN̍Đ
+    void efect(void);
+    // !!! ĐԂ
     // !!! ꎞ~
     // !!! o
   };
