@@ -48,8 +48,7 @@ ColorSurface::~ColorSurface(void) {
 }
 
 void ColorSurface::draw(std::vector<SDL_Rect>& update_rects,
-                        const SDL_Rect* pos, const SDL_Rect* area,
-                        size_t ticks) {
+                        const SDL_Rect* pos, const SDL_Rect* area) {
 
   SDL_Rect draw_rect;
   set_SdlRect(&draw_rect, pos->x, pos->y, area->w, area->h);
@@ -74,7 +73,7 @@ void ColorSurface::forceSetChanged(void) {
 }
 
 
-bool ColorSurface::isChanged(void) {
+bool ColorSurface::isChanged(size_t ticks) {
   bool ret = pimpl->is_changed;
   pimpl->is_changed = false;
   return ret;
