@@ -51,8 +51,17 @@ struct CommonResources::pImpl {
   Surface back_surface;
   boost::shared_ptr<AnimationSurface> icon_surface;
   bool music_initialized;
+  beego::MusicManager* music;              //!< wiȂ̊Ǘ
+  beego::SoundEffectManager* sound_effect; //!< ʉ̊Ǘ
 
-  pImpl(void) : scr(SDL_GetVideoSurface()), music_initialized(false) {
+  pImpl(void)
+  : scr(SDL_GetVideoSurface()), music_initialized(false),
+    music(NULL), sound_effect(NULL) {
+  }
+
+  ~pImpl(void) {
+    delete music;
+    delete sound_effect;
   }
 };
 
@@ -60,11 +69,8 @@ struct CommonResources::pImpl {
 CommonResources::CommonResources(const char* savedir)
   : pimpl(new pImpl),
     gui(new GuiManager), front_layer(new Layer), back_layer(new Layer),
-    music(NULL), sound_effect(NULL), recorder(new TypingRecorder),
-    practice_num(DefaultPracticeNum),
-    //practice_num(1),
-    voice_(new VoicePlayer(VoiceDir)),
-    convert_type(TypingTextConverter::Roman), savedir_(savedir),
+    recorder(new TypingRecorder),
+    voice_(new VoicePlayer(VoiceDir)), savedir_(savedir),
     settings(new AccessSettings(savedir)) {
 
   gui->push_back(back_layer);
@@ -77,8 +83,6 @@ CommonResources::~CommonResources(void) {
 
   // !!! ܂AĂ΂邱Ƃ͑z肵ĂȂ񂾂...
   // !!! ̂AK؂ȃ\bhɈړ
-  delete music;
-  delete sound_effect;
   delete input;
   delete font;
   delete back_layer;
@@ -189,28 +193,28 @@ void CommonResources::initializeMusic(void) {
   if (! pimpl->music_initialized) {
 
     // IuWFNg̐錾
-    music = new MusicManager;
-    if (! music->isInitialized()) {
-      delete music;
-      music = NULL;
+    pimpl->music = new MusicManager;
+    if (! pimpl->music->isInitialized()) {
+      delete pimpl->music;
+      pimpl->music = NULL;
       return;
     }
-    sound_effect = new SoundEffectManager;
+    pimpl->sound_effect = new SoundEffectManager;
 
     // Đ
-    music->setFadeInEffect(PlayFadeIn);
+    pimpl->music->setFadeInEffect(PlayFadeIn);
 
     // y̏
-    music->registerMusic(BackMusic_1, Music1_FilePath);
-    music->registerMusic(BackMusic_2, Music2_FilePath);
+    pimpl->music->registerMusic(BackMusic_1, Music1_FilePath);
+    pimpl->music->registerMusic(BackMusic_2, Music2_FilePath);
 
-    sound_effect->registerEffect(SoundEffect_1, Effect1_FilePath);
-    sound_effect->registerEffect(SoundEffect_2, Effect2_FilePath);
+    pimpl->sound_effect->registerEffect(SoundEffect_1, Effect1_FilePath);
+    pimpl->sound_effect->registerEffect(SoundEffect_2, Effect2_FilePath);
 
 #if 0
-    sound_effect->registerEffect(Decide, Decide_FilePath);
-    sound_effect->registerEffect(Type, Type_FilePath);
-    sound_effect->registerEffect(Miss, Miss_FilePath);
+    pimpl->sound_effect->registerEffect(Decide, Decide_FilePath);
+    pimpl->sound_effect->registerEffect(Type, Type_FilePath);
+    pimpl->sound_effect->registerEffect(Miss, Miss_FilePath);
 #else
     // y\[X hyakutypingrc.txt w\ɂ
     std::string dir_path = std::string(MusicDirectory);
@@ -218,11 +222,19 @@ void CommonResources::initializeMusic(void) {
     std::string type_file = dir_path + settings->effect_type_;
     std::string miss_file = dir_path + settings->effect_miss_;
 
-    sound_effect->registerEffect(Decide, decide_file.c_str());
-    sound_effect->registerEffect(Type, type_file.c_str());
-    sound_effect->registerEffect(Miss, miss_file.c_str());
+    pimpl->sound_effect->registerEffect(Decide, decide_file.c_str());
+    pimpl->sound_effect->registerEffect(Type, type_file.c_str());
+    pimpl->sound_effect->registerEffect(Miss, miss_file.c_str());
 #endif
 
+    // !!! ɁApImpl::user_index_ 錾H
+    size_t user_index = settings->user_index_;
+    int volume = settings->music_volume_[user_index];
+    updateSoundVolume(volume);
+
+    volume = settings->effect_volume_[user_index];
+    updateEffectVolume(volume);
+
     pimpl->music_initialized = true;
   }
 }
@@ -257,7 +269,7 @@ void CommonResources::deleteUser(int user_index) {
 
 
 void CommonResources::updateUserLable(void) {
-  int user_index = settings->user_index_;
+  size_t user_index = settings->user_index_;
   const char* user_name = settings->user_names_[user_index].c_str();
 
   if (strlen(user_name) <= 0) {
@@ -278,3 +290,117 @@ void CommonResources::updateUserLable(void) {
               TextOffset);
   user_label->setPosition(&position);
 }
+
+
+TypingTextConverter::ConvertType CommonResources::getConvertType(void) {
+
+  size_t user_index = settings->user_index_;
+  return (settings->convert_mode_[user_index] == 0) ?
+    TypingTextConverter::Roman : TypingTextConverter::Kana;
+}
+
+
+int CommonResources::getPracticeNum(void) {
+
+  size_t user_index = settings->user_index_;
+  return settings->practice_num_[user_index];
+}
+
+
+int CommonResources::getPracticeNumIndex(void) {
+
+  int index = 0;
+  switch (getPracticeNum()) {
+  case 10:
+    index = 1;
+    break;
+
+  case 50:
+    index = 2;
+    break;
+
+  case 100:
+    index = 3;
+    break;
+  }
+
+  return index;
+}
+
+
+void CommonResources::setPracticeNumIndex(size_t index) {
+
+  int num_array[] = { 5, 10, 50, 100 };
+  if (index >= sizeof(num_array)/sizeof(num_array[0])) {
+    return;
+  }
+
+  size_t user_index = settings->user_index_;
+  settings->practice_num_[user_index] = num_array[index];
+}
+
+
+void CommonResources::setNextMusic(int id) {
+  if (pimpl->music) {
+    pimpl->music->setNextMusic(id);
+  }
+}
+
+
+bool CommonResources::nowSoundPlaying(void) {
+  if (! pimpl->music) {
+    return false;
+  }
+
+  return pimpl->music->nowPlaying();
+}
+
+
+void CommonResources::stopMusic(int fadeout_msec) {
+  if (pimpl->music) {
+    pimpl->music->stop(fadeout_msec);
+  }
+}
+
+
+void CommonResources::haltMusic(void) {
+  if (pimpl->music) {
+    pimpl->music->halt();
+  }
+}
+
+
+void CommonResources::updateSoundVolume(int percent) {
+  if (pimpl->music) {
+    pimpl->music->updateVolume(percent);
+  }
+}
+
+
+void CommonResources::playEffect(int id) {
+  if (pimpl->music) {
+    pimpl->sound_effect->play(id);
+  }
+}
+
+
+bool CommonResources::nowEffectPlaying(void) {
+  if (! pimpl->music) {
+    return false;
+  }
+  return pimpl->sound_effect->nowPlaying();
+}
+
+
+void CommonResources::stopEffect(void) {
+  if (pimpl->music) {
+    pimpl->sound_effect->stop();
+  }
+}
+
+
+void CommonResources::updateEffectVolume(int percent) {
+  if (pimpl->music) {
+    pimpl->sound_effect->updateVolume(percent);
+  }
+}
