@@ -14,7 +14,8 @@
 
 
 namespace beego {
-  extern SDL_Surface* createSurface(const char data[], int width, int height);
+  extern SDL_Surface* createSurface(const unsigned char data[],
+                                    int width, int height);
 };
 
 #endif /* !CREATE_SURFACE_FROM_ARRAY_H */
