@@ -7,6 +7,7 @@
   $Id$
 
   \todo PC ̃[UƏdȂAʂ
+  \todo TextInput AhX͉\ɂ
 */
 
 #include "CreateUser.h"
@@ -24,6 +25,7 @@
 #include "TextSurface.h"
 #include "ImageSurface.h"
 #include "LabelComponent.h"
+#include "ButtonComponent.h"
 #include "TextInputComponent.h"
 #include "InputReceiveComponent.h"
 #include "SelectComponent.h"
@@ -1017,8 +1019,9 @@ struct CreateUser::pImpl {
   Surface title_surface;
   Component title_label;
   TextProperty back_property;
+  TextProperty back_focus_property_;
+  boost::shared_ptr<ButtonComponent> back_button_;
   Surface back_surface;
-  Component back_label;
 
   pImpl(void)
     : common(CommonResources::getObject()),
@@ -1029,8 +1032,13 @@ struct CreateUser::pImpl {
       title_label(new LabelComponent(title_surface)),
       back_property(common->font, CreateUser_back_message,
                     NormalSize, Fore, Back, true),
-      back_surface(new TextSurface(back_property)),
-      back_label(new LabelComponent(back_surface)) {
+      back_focus_property_(common->font, CreateUser_back_message,
+                          NormalSize, Blue, Back, true),
+      back_button_(new ButtonComponent),
+      back_surface(new TextSurface(back_property)) {
+
+    ButtonComponent::createButton(back_button_, back_property,
+                                  back_focus_property_, back_focus_property_);
 
     // ^Cgʒu
     SDL_Rect position;
@@ -1039,9 +1047,9 @@ struct CreateUser::pImpl {
     title_label->setPosition(&position);
 
     // ߂邽߂̃bZ[Wʒu
-    set_SdlRect(&position, rightPosition(back_label, 640) - TextOffset,
-                bottomPosition(back_label, 480) - TextOffset);
-    back_label->setPosition(&position);
+    set_SdlRect(&position, rightPosition(back_button_, 640) - TextOffset,
+                bottomPosition(back_button_, 480) - TextOffset);
+    back_button_->setPosition(&position);
   }
 
   void placeComponents(void) {
@@ -1050,7 +1058,7 @@ struct CreateUser::pImpl {
     ProgressChanger::getObject(common)->changeProgress(0);
 
     common->front_layer->push_front(title_label);
-    common->front_layer->push_front(back_label);
+    common->front_layer->push_front(back_button_);
   }
 
   void removeComponents(void) {
@@ -1061,7 +1069,7 @@ struct CreateUser::pImpl {
     CompleteState::getObject(common)->removeComponents();
 
     common->front_layer->remove(title_label);
-    common->front_layer->remove(back_label);
+    common->front_layer->remove(back_button_);
   }
 
   static int webAccess_thread(void* args) {
@@ -1109,7 +1117,7 @@ void CreateUser::run(void) {
     pimpl->scheduler.update();
 
     // I
-    quit |= pimpl->scheduler.isTerminated();
+    quit |= pimpl->scheduler.isTerminated() || pimpl->back_button_->isDecided();
     input.update_all();
     gui->update();
     if (input.haveQuitEvent()) {
