@@ -14,11 +14,13 @@
 
 #include "SurfaceInterface.h"
 #include "GridTypes.h"
+#include "PlaceOption.h"
 #include <memory>
 
 
 namespace beego {
-  class TtfResource;
+  //class TtfResource;
+  class TextProperty;
 
   /*!
     \brief }`̕`T[tFX
@@ -45,14 +47,15 @@ namespace beego {
 
     void clear(void);
 
-    void setFontResource(TtfResource* font);
+    //void setFontResource(TtfResource* font);
     void setBackgroundColor(Uint32 color);
     void setNoBackground(void);
     void drawPoint(const Grid<int>& point, Uint32 color);
     void drawPoints(const std::vector<Grid<int> >& points, Uint32 color);
     void drawLine(const Grid<int>& p1, const Grid<int>& p2, Uint32 color);
     void drawLines(const std::vector<Grid<int> >& points, Uint32 color);
-    // void drawText()
+    void drawText(const Grid<int>& position,
+                  const TextProperty& text, int mode = None);
   };
 };
 
