@@ -10,6 +10,7 @@
 #include "DrawPrimitive.h"
 #include "SdlUtils.h"
 #include "GuiColors.h"
+#include "TextSurface.h"
 
 
 static SDL_Surface* Scr = NULL;
@@ -79,3 +80,18 @@ void beego::draw_line(int x1, int y1, int x2, int y2, Uint32 color) {
     }
   }
 }
+
+
+void beego::draw_text(int x, int y, boost::shared_ptr<TextSurface> text) {
+
+  size_t w = text->getWidth();
+  size_t h = text->getHeight();
+  SDL_Rect pos;
+  set_SdlRect(&pos, x, y, w, h);
+
+  SDL_Rect area;
+  set_SdlRect(&area, 0, 0, w, h);
+
+  std::vector<SDL_Rect> dummy;
+  text->draw(dummy, &pos, &area);
+}
