@@ -18,6 +18,8 @@ enum {
   Fore = beego::Black,
   Back = beego::Gray12,
   Selected = beego::Blue,
+
+  Pink = 0xffc0cbff,
 };
 
 // tHgTCY
@@ -45,12 +47,17 @@ enum {
   ResultWidth = 420,
   TextOffset = 8,
 
+  IconOffset = -48,
+
   MenuOffset = 70,
   ResultOffset = 50,
   SubOffset = 45,
   BottomOffset = 48,
   SampleOffset = 38,
   RomanOffset = 30,
+
+  GraphWidth = 540,
+  GraphHeight = 360,
 };
 
 #endif /* !POSITION_DEFINITION_H */
