@@ -56,20 +56,21 @@ void FillSurface::draw(std::vector<SDL_Rect>& update_rects,
   // !!! ƂAarea  for ̏͌vZׂ
   std::vector<SDL_Rect> common_area;
   std::vector<SDL_Rect> unique_area;
-  int y_offset = -(area->y % surface_height);
-  int x_offset = -(area->x % surface_width);
+  int y_offset = -(area->y % static_cast<int>(surface_height));
+  int x_offset = -(area->x % static_cast<int>(surface_width));
 
   SDL_Rect eval_area;
   set_SdlRect(&eval_area, pos->x, pos->y, area->w, area->h);
 
   //fprintf(stderr, "x_offset: %d\n", x_offset);
-  for (int h = y_offset;
-       h < static_cast<int>(pimpl->height); h += surface_height) {
-    for (int w = x_offset;
-         w < static_cast<int>(pimpl->width); w += surface_width) {
+  for (int h = y_offset; h < static_cast<int>(pimpl->height);
+       h += static_cast<int>(surface_height)) {
+    for (int w = x_offset; w < static_cast<int>(pimpl->width);
+         w += static_cast<int>(surface_width)) {
       SDL_Rect eval_pos;
       set_SdlRect(&eval_pos, pos->x + w, pos->y + h,
-                  surface_width, surface_height);
+                  static_cast<int>(surface_width),
+                  static_cast<int>(surface_height));
 
       // !!! draw_area `Apčĕ`s
       // !!! for ŌJԂ͈͂ς̂Œӂ邱
