@@ -8,6 +8,7 @@
 
   \todo |bvAbvŃj[ڂ̐s
   \todo j[̐
+  \todo [UACȒAOptionMenu ƍ킹
 */
 
 #include "FirstMenu.h"
@@ -36,8 +37,6 @@
 #include "ComboBoxComponent.h"
 #include "InputHandler.h"
 #include "CreateSurfaceFromArray.h"
-#include "MusicManager.h"
-#include "SoundEffectManager.h"
 #include "SdlUtils.h"
 #include "Delay.h"
 
@@ -55,7 +54,6 @@ struct FirstMenu::pImpl {
   Surface version_surface;
   Component version_label;
 
-  // !!! Ƃ肠A摜ƂĒt
   Surface user_bmp_surface;
   Surface white_bmp_surface;
   boost::shared_ptr<MultiSurface> focus_surface;
@@ -83,7 +81,6 @@ struct FirstMenu::pImpl {
                                                     white_bmp_height), true)),
       focus_surface(new MultiSurface(white_bmp_width, white_bmp_height)),
       user_button(new ButtonComponent),
-      //user_label(new LabelComponent(user_bmp_surface)),
       user_combobox(new ComboBoxComponent)
   {
 
@@ -185,7 +182,7 @@ struct FirstMenu::pImpl {
     }
 
     // CfbNXw
-    user_combobox->setSelected(common->settings->user_index_);
+    user_combobox->setSelected(static_cast<int>(common->settings->user_index_));
 
     // ʒuݒ
     SDL_Rect position;
@@ -193,7 +190,7 @@ struct FirstMenu::pImpl {
                 rightPosition(user_combobox, 640) - TextOffset, TextOffset);
     user_combobox->setPosition(&position);
 
-    position.x -= TextOffset + user_button->getWidth();
+    position.x -= TextOffset + static_cast<int>(user_button->getWidth());
     position.y = TextOffset / 2;
     user_button->setPosition(&position);
   }
@@ -201,11 +198,9 @@ struct FirstMenu::pImpl {
   void playDecideEffect(int selected) {
 
     // !!! Is\ȍڂ肵ƂɉςȂAύX
-    if (common->music) {
-      if (selected != 4) {
-        // uIv̂Ƃ͌ʉ炳Ȃ
-        common->sound_effect->play(Decide);
-      }
+    if (selected != 4) {
+      // uIv̂Ƃ͌ʉ炳Ȃ
+      common->playEffect(Decide);
     }
   }
 };
@@ -228,9 +223,7 @@ void FirstMenu::run(void) {
   pimpl->updateUserComboBox();
 
   // y̍Đ
-  if (pimpl->common->music) {
-    pimpl->common->music->setNextMusic(BackMusic_1);
-  }
+  pimpl->common->setNextMusic(BackMusic_1);
 
   GuiManager* gui = pimpl->common->gui;
   InputHandler& input = *pimpl->common->input;
@@ -242,7 +235,7 @@ void FirstMenu::run(void) {
     if (0 || (selected >= 0) || user_config) {
       //selected = 3;
 
-      // !!! Ƃ肠AŌ艹炷
+      // 艹炷
       pimpl->playDecideEffect(selected);
       pimpl->removeComponents();
 
