@@ -17,6 +17,7 @@
 
 namespace beego {
   class TtfResource;
+  class TextProperty;
 
   class GraphComponent : public ComponentInterface {
     GraphComponent(const GraphComponent& rhs);
@@ -42,6 +43,7 @@ namespace beego {
     // !!! w肷܂ł́A
     void setBackgroundColor(Uint32 color);
 
+    void drawTitle(const TextProperty& title);
     void registerLine(std::vector<Grid<double> >& points, Uint32 color);
     void create(size_t width, size_t height, TtfResource* font);
     void clear(void);
