@@ -24,6 +24,7 @@ namespace beego {
 
     bool left_clicked;
     bool left_released;
+    bool left_pressing;
 
     class InputKey {
     public:
@@ -44,7 +45,7 @@ namespace beego {
 
     InputEvent(void)
       : mx(0), my(0), mouse_moved(false), wheels(0),
-        left_clicked(false), left_released(false) {
+        left_clicked(false), left_released(false), left_pressing(false) {
     }
 
     static bool isPressed(const InputEvent& event, SDLKey key);
