@@ -28,13 +28,13 @@ struct InputReceiveComponent::pImpl {
 
     // !!! Amearge? ɒu
     for (InputEvent::InputKeys::const_iterator it = event.key_pressed.begin();
-	 it != event.key_pressed.end(); ++it) {
+         it != event.key_pressed.end(); ++it) {
       input_event.key_pressed.push_back(*it);
     }
 
     // !!! Amearge? ɒu
     for (InputEvent::SdlKeys::const_iterator it = event.key_released.begin();
-	 it != event.key_released.end(); ++it) {
+         it != event.key_released.end(); ++it) {
       input_event.key_released.push_back(*it);
     }
   }
@@ -56,8 +56,8 @@ InputReceiveComponent::~InputReceiveComponent(void) {
 
 
 void InputReceiveComponent::addSurfaceList(SurfaceList& surfaces,
-					   const SDL_Rect* area,
-					   size_t ticks) {
+                                           const SDL_Rect* area,
+                                           size_t ticks) {
   // Ȃ
 }
 
@@ -82,7 +82,8 @@ size_t InputReceiveComponent::getHeight(void) {
 }
 
 
-void InputReceiveComponent::applyInput(const InputEvent& event) {
+void InputReceiveComponent::applyInput(const InputEvent& event,
+                                       std::vector<SDL_Rect>& applied_rects) {
   pimpl->updateEvent(event);
 }
 
