@@ -6,7 +6,6 @@
 
   $Id$
 
-  \todo ca̐ɕ\
   \todo ܂莚p̃VbtNXKp
 */
 
@@ -32,8 +31,6 @@
 #include "TextSurface.h"
 #include "TextProperty.h"
 #include "LabelComponent.h"
-#include "MusicManager.h"
-#include "SoundEffectManager.h"
 #include "GetTicks.h"
 #include "Delay.h"
 #include "SdlUtils.h"
@@ -151,7 +148,7 @@ struct KimarijiPractice::pImpl {
       // uX ṽx쐬
       std::vector<Uint16> num_str;
       char buffer[4];
-      sprintf(buffer, "%d", common->practice_num);
+      sprintf(buffer, "%d", common->getPracticeNum());
       ustrcat(num_str, buffer);
       ustrcat(num_str, KimarijiPractice_PrologueSubTitle);
       TextProperty text_property(common->font, &num_str[0],
@@ -168,15 +165,13 @@ struct KimarijiPractice::pImpl {
 
       placeComponents();
 
-      if (common->music) {
-        // y̒~҂
-        while (common->music->nowPlaying()) {
-          delay(10);
-        }
-
-        // ʉ̍ĐJn
-        common->sound_effect->play(SoundEffect_1);
+      // y̒~҂
+      while (common->nowSoundPlaying()) {
+        delay(10);
       }
+
+      // ʉ̍ĐJn
+      common->playEffect(SoundEffect_1);
       first_ticks = GetTicks();
     }
 
@@ -196,12 +191,8 @@ struct KimarijiPractice::pImpl {
       // zuR|[lg폜
       removeComponents();
 
-      // ʉ̒~ƁAy̍Đ
-      if (common->music) {
-
-        // y̍Đ
-        common->music->setNextMusic(BackMusic_2);
-      }
+      // y̍Đ
+      common->setNextMusic(BackMusic_2);
     }
 
     void placeComponents(void) {
@@ -214,9 +205,7 @@ struct KimarijiPractice::pImpl {
       common->front_layer->remove(title_label);
       common->front_layer->remove(subTitle_label);
 
-      if (common->music) {
-        common->sound_effect->stop();
-      }
+      common->stopEffect();
     }
   };
 
@@ -229,7 +218,8 @@ struct KimarijiPractice::pImpl {
 
     TypingState(CommonResources* common_obj)
       : common(common_obj),
-        kimariji_input(KimarijiTyping), typing_complete(false) {
+        kimariji_input(KimarijiTyping, common->getConvertType()),
+        typing_complete(false) {
     }
 
   public:
@@ -289,10 +279,8 @@ struct KimarijiPractice::pImpl {
         kimariji_input.removeInputComponents();
         typing_complete = true;
 
-        if (common->music) {
-          // ʉ̍Đ
-          common->sound_effect->play(Decide);
-        }
+        // ʉ̍Đ
+        common->playEffect(Decide);
       }
     }
 
@@ -438,7 +426,7 @@ struct KimarijiPractice::pImpl {
   pImpl(void)
     : common(CommonResources::getObject()),
       scheduler(0, common) {
-    TypingState::getObject(common)->setPracticeNum(common->practice_num);
+    TypingState::getObject(common)->setPracticeNum(common->getPracticeNum());
   }
 
   void removeComponents(void) {
