@@ -36,7 +36,7 @@ namespace beego {
     void applyInput(ComponentList& components, const InputEvent& event,
                     std::vector<SDL_Rect>& applied_rects);
     void redraw(std::vector<SDL_Rect>& update_rects,
-                SurfaceList& surfaces, size_t ticks);
+                SurfaceList& surfaces);
     void push_front(Layer* layer);
     void push_back(Layer* layer);
     void insert(const Layer* dst, Layer* layer);
