@@ -15,7 +15,6 @@
 #include "GridTypes.h"
 #include "SdlUtils.h"
 #include "Layer.h"
-#include "Component.h"
 #include "RedrawSurface.h"
 #include "InputEvent.h"
 #include "EvaluateArea.h"
@@ -131,7 +130,7 @@ struct MenuComponent::pImpl {
 
   void setIconComponent(Component icon, int x_offset, int y_offset, int mode) {
 
-    std::swap(icon_component_, icon);
+    icon_component_ = icon;
     icon_placed_ = true;
 
     icon_offset_.x = x_offset;
