@@ -20,7 +20,6 @@
 #include "LabelComponent.h"
 #include "MenuComponent.h"
 #include "ButtonComponent.h"
-#include "SoundEffectManager.h"
 #include "SdlUtils.h"
 #include "Delay.h"
 
@@ -49,7 +48,6 @@ struct NetworkMenu::pImpl {
     title_label->setPosition(&position);
 
     // j[̐Aʒuݒ
-    // j[̍ڂ쐬
     const Uint16 *titles[] = {
       NetworkMenu_player, NetworkMenu_data,
       NetworkMenu_replay, NetworkMenu_back,
@@ -111,11 +109,8 @@ void NetworkMenu::run(void) {
     int selected = pimpl->menu->getDecided();
     if (selected >= 0) {
 
-      // !!! Ƃ肠AŌ艹炷
-      // !!! Is\ȍڂ肵ƂɉςȂAύX
-      if (pimpl->common->music) {
-        pimpl->common->sound_effect->play(Decide);
-      }
+      // 艹炷
+      pimpl->common->playEffect(Decide);
 
       pimpl->removeComponents();
       if (selected == 0) {
