@@ -23,8 +23,7 @@ NullSurface::~NullSurface(void) {
 
 
 void NullSurface::draw(std::vector<SDL_Rect>& update_rects,
-                       const SDL_Rect* pos, const SDL_Rect* area,
-                       size_t ticks) {
+                       const SDL_Rect* pos, const SDL_Rect* area) {
   // Ȃ
 }
 
@@ -44,7 +43,7 @@ void NullSurface::forceSetChanged(void) {
 }
 
 
-bool NullSurface::isChanged(void) {
+bool NullSurface::isChanged(size_t ticks) {
   return false;
 }
 
