@@ -11,6 +11,7 @@
 */
 
 #include "ComponentInterface.h"
+#include "Component.h"
 #include "PlaceOption.h"
 #include <boost/shared_ptr.hpp>
 #include <memory>
@@ -40,12 +41,17 @@ namespace beego {
                     std::vector<SDL_Rect>& applied_rects);
     void registerLayer(Layer* layer);
 
+    void setIconComponent(Component icon,
+                          int x_offset, int y_offset, int mode = None);
     void addItem(const TextProperty& title,
                  boost::shared_ptr<ComponentInterface> component,
                  int x_offset = 0, int y_offset = 0,
                  int place_mode = None);
     void setItemsOffset(int x_offset, int y_offset);
     void addItemOffset(int x_offset, int y_offset);
+
+    // !!! ɃR|[lgɓ͂^邽߂̃\bh
+    // !!! }EX͌ɂł邩H
   };
 };
 
