@@ -5,17 +5,17 @@
   \author Satofumi KAMIMURA
 
   $Id$
-
-  \todo â̗KR{{bNXőI\ɂ
 */
 
 #include "PracticeMenu.h"
 #include "PracticeMenu_uni.h"
+#include "PracticeNum_uni.h"
 #include "DrawsDefinition.h"
 #include "SystemDefinition.h"
 #include "ShimonokuPractice.h"
 #include "KimarijiPractice.h"
 #include "CommonResources.h"
+#include "AccessSettings.h"
 #include "ResourceDefinition.h"
 #include "GuiManager.h"
 #include "Layer.h"
@@ -25,8 +25,7 @@
 #include "LabelComponent.h"
 #include "MenuComponent.h"
 #include "ButtonComponent.h"
-#include "MusicManager.h"
-#include "SoundEffectManager.h"
+#include "ComboBoxComponent.h"
 #include "SdlUtils.h"
 #include "Delay.h"
 
@@ -40,6 +39,7 @@ struct PracticeMenu::pImpl {
   Surface title_surface;
   Component title_label;
   boost::shared_ptr<MenuComponent> menu;
+  boost::shared_ptr<ComboBoxComponent> num_combobox_;
 
   pImpl(void)
     : common(CommonResources::getObject()),
@@ -47,7 +47,9 @@ struct PracticeMenu::pImpl {
       title_property(font, PracticeMenu_title, TitleSize,
                      Fore, Back, true),
       title_surface(new TextSurface(title_property)),
-      title_label(new LabelComponent(title_surface)), menu(new MenuComponent) {
+      title_label(new LabelComponent(title_surface)), menu(new MenuComponent),
+      num_combobox_(new ComboBoxComponent)
+  {
 
     SDL_Rect position;
     // !!! 640, 480 ܂̒萔͒u
@@ -78,34 +80,60 @@ struct PracticeMenu::pImpl {
     menu->setSelected(0);
     menu->setIconComponent(common->menu_icon, IconOffset, 0, Middle | Left);
 
+    // R{{bNX̍쐬
+    num_combobox_->setFrameColor(Pink);
+    num_combobox_->setDecidedBackgroundColor(Pink);
+    num_combobox_->setSelectedBackgroundColor(Pink);
+    num_combobox_->setRightOffset(TextOffset);
+
+    Uint16 dummy[] = { 0x0 };
+    TextProperty normal(common->font, dummy, NormalSize, Fore, Pink, false);
+    TextProperty selected(common->font, dummy, NormalSize, Blue, Pink, false);
+
+    const Uint16* num_text[] = {
+      PracticeNum_5, PracticeNum_10, PracticeNum_50, PracticeNum_100,
+    };
+    for (size_t i = 0; i < sizeof(num_text)/sizeof(num_text[0]); ++i) {
+      normal.utext = num_text[i];
+      selected.utext = num_text[i];
+      boost::shared_ptr<ButtonComponent> new_button(new ButtonComponent);
+      ButtonComponent::createButton(new_button, normal, selected, selected);
+      num_combobox_->addItem(new_button);
+    }
+    num_combobox_->setSelected(common->getPracticeNumIndex());
+
+    // R|[lg̔zu
     set_SdlRect(&position, centerPosition(menu, 640/2), 480/4 + MenuOffset);
     menu->setPosition(&position);
-    //fprintf(stderr, "practice_menu: %d, %d\n", position.x, position.y);
+
+    // ʒuݒ
+    set_SdlRect(&position,
+                rightPosition(num_combobox_, 640) - TextOffset,
+                TextOffset + NormalSize + TextOffset);
+    num_combobox_->setPosition(&position);
   }
 
   void placeComponents(void) {
     common->front_layer->push_front(title_label);
     common->front_layer->push_front(menu);
     common->front_layer->push_front(common->user_label);
+    common->front_layer->push_front(num_combobox_);
   }
 
   void removeComponents(void) {
     common->front_layer->remove(title_label);
     common->front_layer->remove(menu);
     common->front_layer->remove(common->user_label);
+    common->front_layer->remove(num_combobox_);
   }
 
   // y̒~
   void stopMusic(void) {
-    if (common->music) {
-      common->music->stop(StopFadeOut);
-    }
+    common->stopMusic(StopFadeOut);
   }
 
   void playMusic(void) {
-    if (common->music) {
-      common->music->setNextMusic(BackMusic_1);
-    }
+    common->setNextMusic(BackMusic_1);
   }
 };
 
@@ -127,14 +155,17 @@ void PracticeMenu::run(void) {
   bool quit = false;
   while (quit == false) {
 
+    // R{{bNXɂK̕ύX
+    if (pimpl->num_combobox_->isSelectChanged()) {
+      pimpl->common->setPracticeNumIndex(pimpl->num_combobox_->getSelected());
+      pimpl->common->settings->save();
+    }
+
     int selected = pimpl->menu->getDecided();
     if (selected >= 0) {
 
-      // !!! Ƃ肠AŌ艹炷
-      // !!! Is\ȍڂ肵ƂɉςȂAύX
-      if (pimpl->common->music) {
-        pimpl->common->sound_effect->play(Decide);
-      }
+      // 艹炷
+      pimpl->common->playEffect(Decide);
 
       pimpl->removeComponents();
       if (selected == 0) {
