@@ -342,8 +342,8 @@ struct RemoveUser::pImpl {
   Surface title_surface;
   Component title_label;
   TextProperty back_property;
-  Surface back_surface;
-  Component back_label;
+  TextProperty back_focus_property_;
+  boost::shared_ptr<ButtonComponent> back_button_;
 
   pImpl(void)
     : common(CommonResources::getObject()),
@@ -354,8 +354,12 @@ struct RemoveUser::pImpl {
       title_label(new LabelComponent(title_surface)),
       back_property(common->font, RemoveUser_back_message,
                     NormalSize, Fore, Back, true),
-      back_surface(new TextSurface(back_property)),
-      back_label(new LabelComponent(back_surface)) {
+      back_focus_property_(common->font, RemoveUser_back_message,
+                           NormalSize, Blue, Back, true),
+      back_button_(new ButtonComponent()) {
+
+    ButtonComponent::createButton(back_button_, back_property,
+                                  back_focus_property_, back_focus_property_);
 
     // ^Cgʒu
     SDL_Rect position;
@@ -364,20 +368,20 @@ struct RemoveUser::pImpl {
     title_label->setPosition(&position);
 
     // ߂邽߂̃bZ[Wʒu
-    set_SdlRect(&position, rightPosition(back_label, 640) - TextOffset,
-                bottomPosition(back_label, 480) - TextOffset);
-    back_label->setPosition(&position);
+    set_SdlRect(&position, rightPosition(back_button_, 640) - TextOffset,
+                bottomPosition(back_button_, 480) - TextOffset);
+    back_button_->setPosition(&position);
   }
 
   void placeComponents(void) {
     common->front_layer->push_front(title_label);
-    common->front_layer->push_front(back_label);
+    common->front_layer->push_front(back_button_);
   }
 
   void removeComponents(void) {
     YesNoState::getObject(common)->removeComponents();
     common->front_layer->remove(title_label);
-    common->front_layer->remove(back_label);
+    common->front_layer->remove(back_button_);
   }
 };
 
@@ -404,7 +408,7 @@ void RemoveUser::run(void) {
     pimpl->scheduler.update();
 
     // I
-    quit |= pimpl->scheduler.isTerminated();
+    quit |= pimpl->scheduler.isTerminated() || pimpl->back_button_->isDecided();
     gui->update();
     input.update_all();
     if (input.haveQuitEvent()) {
