@@ -25,7 +25,6 @@
 #include "TextProperty.h"
 #include "TextFadeSurface.h"
 #include "LabelComponent.h"
-#include "MusicManager.h"
 #include "SdlUtils.h"
 #include "Delay.h"
 #include "UtfString.h"
@@ -125,7 +124,7 @@ struct ResultDrawer::pImpl {
 
     // 
     char buffer[13];
-    int waka_num = common->recorder->getWakaNum();
+    int waka_num = static_cast<int>(common->recorder->getWakaNum());
     sprintf(buffer, "%d", waka_num);
     std::vector<Uint16> num_text;
     ustrcat(num_text, buffer);
@@ -204,7 +203,7 @@ struct ResultDrawer::pImpl {
 
       // 
       num_text.clear();
-      int miss_types = common->recorder->getMissTypes();
+      int miss_types = static_cast<int>(common->recorder->getMissTypes());
       sprintf(buffer, "%d", miss_types);
       ustrcat(num_text, buffer);
       text_property.utext = &num_text[0];
@@ -287,15 +286,8 @@ void ResultDrawer::createResult(void) {
   // !!! ŔzuĂяốAȂ񂩕ςȋC邪A܂Â
   pimpl->placeComponents();
 
-  if (pimpl->common->music) {
-    // y̒~҂
-    pimpl->common->music->stop(3000);
-
-    // ʉ̍ĐJn
-    // !!! ýAׂĂ̕\IƂɁAȂ炷xȁH
-    // !!! SoundEffect_2 悩
-    //pimpl->common->music->setNextMusic(BackMusic_4, 1);
-  }
+  // y̒~҂
+  pimpl->common->stopMusic(3000);
 }
 
 
@@ -314,9 +306,7 @@ void ResultDrawer::removeComponents(void) {
   pimpl->removeComponents();
 
   // y̒~
-  if (pimpl->common->music) {
-    pimpl->common->music->halt();
-  }
+  pimpl->common->haltMusic();
 }
 
 
