@@ -10,6 +10,7 @@
 #include "RomanCreator.h"
 #include "RomanConvertTable.h"
 #include "UtfString.h"
+#include <string>
 
 using namespace beego;
 
@@ -18,7 +19,7 @@ struct RomanCreator::pImpl {
   const Uint16* convert_table;
   unsigned int max_length;
   std::basic_string<Uint16> converted;
-  std::string converted_char;
+  std::vector<Uint16> converted_char;
 
   pImpl(const Uint16* convertTable, unsigned int maxLength)
     : convert_table(convertTable), max_length(maxLength) {
@@ -51,7 +52,7 @@ RomanCreator::~RomanCreator(void) {
 }
 
 
-void RomanCreator::convert(std::string& dst, const Uint16* input) {
+void RomanCreator::convert(std::vector<Uint16>& dst, const Uint16* input) {
   pimpl->converted.clear();
 
   // ϊ
