@@ -12,7 +12,7 @@
 
 #include <SDL.h>
 #include <memory>
-#include <string>
+#include <vector>
 
 
 namespace beego {
@@ -26,7 +26,7 @@ namespace beego {
   public:
     RomanCreator(void);
     ~RomanCreator(void);
-    void convert(std::string& dst, const Uint16* input);
+    void convert(std::vector<Uint16>& dst, const Uint16* input);
   };
 };
 
