@@ -10,11 +10,7 @@
   $Id$
 */
 
-#ifdef MSC
-#include "SDL_win.h"
-#else
 #include <SDL.h>
-#endif
 #include <vector>
 
 
@@ -31,7 +27,7 @@ namespace beego {
   extern void set_SdlRect(SDL_Rect* rect, int x, int y, int w = 0, int h = 0);
 
   extern void add_SdlRect(std::vector<SDL_Rect>& list,
-			  int x, int y, int w = 0, int h = 0);
+                          int x, int y, int w = 0, int h = 0);
 
   /*!
     \brief SDL_Color ւ̑֐
