@@ -11,8 +11,7 @@
 */
 
 #include "TypingMode.h"
-#include <memory>
-#include <vector>
+#include "TypingTextConverter.h"
 
 
 /*!
@@ -32,7 +31,8 @@ public:
 
     \param mode [i] ^CsO[h
   */
-  explicit ShimonokuInput(TypingMode mode);
+  explicit ShimonokuInput(TypingMode mode,
+                          TypingTextConverter::ConvertType type);
   ~ShimonokuInput(void);
 
   /*!
