@@ -6,8 +6,6 @@
 
   $Id$
 
-  \todo ca̐ɕ\
-  \todo rݏグ@\̒ǉ
   \todo L[\
   \todo Iɂ́ACD-ROM  T / TȂ IvVőIł悤ɂׂ
 */
@@ -29,8 +27,6 @@
 #include "Layer.h"
 #include "BaseEntity.h"
 #include "StateMachine.h"
-#include "MusicManager.h"
-#include "SoundEffectManager.h"
 #include "GetTicks.h"
 #include "Delay.h"
 #include "TextSurface.h"
@@ -154,7 +150,7 @@ struct ShimonokuPractice::pImpl {
       // uX ṽx쐬
       std::vector<Uint16> num_str;
       char buffer[4];
-      sprintf(buffer, "%d", common->practice_num);
+      sprintf(buffer, "%d", common->getPracticeNum());
       ustrcat(num_str, buffer);
       ustrcat(num_str, ShimonokuPractice_PrologueSubTitle);
       TextProperty text_property(common->font, &num_str[0],
@@ -171,21 +167,20 @@ struct ShimonokuPractice::pImpl {
 
       placeComponents();
 
-      if (common->music) {
-        // y̒~҂
-        // !!! ^CAEgł悤ɂׂ
-        while (common->music->nowPlaying()) {
-          delay(10);
-        }
-
-        // ʉ̍ĐJn
-        common->sound_effect->play(SoundEffect_1);
+      // y̒~҂
+      // !!! ^CAEgł悤ɂׂ
+      while (common->nowSoundPlaying()) {
+        delay(10);
       }
 
+      // ʉ̍ĐJn
+      common->playEffect(SoundEffect_1);
+
       first_ticks = GetTicks();
 
       // a CD-ROM ZbgĂ邩̊mFƁAf[^ǂݏo
       common->gui->update();
+      // !!! XbhɂȂƁA`悪A
       common->voice_->checkCd();
     }
 
@@ -206,12 +201,8 @@ struct ShimonokuPractice::pImpl {
       // zuR|[lg폜
       removeComponents();
 
-      // ʉ̒~ƁAy̍Đ
-      if (common->music) {
-
-        // y̍Đ
-        common->music->setNextMusic(BackMusic_2);
-      }
+      // y̍Đ
+      common->setNextMusic(BackMusic_2);
     }
 
     void placeComponents(void) {
@@ -225,9 +216,7 @@ struct ShimonokuPractice::pImpl {
       common->front_layer->remove(title_label);
       common->front_layer->remove(subTitle_label);
 
-      if (common->music) {
-        common->sound_effect->stop();
-      }
+      common->stopEffect();
     }
   };
 
@@ -240,7 +229,8 @@ struct ShimonokuPractice::pImpl {
 
     TypingState(CommonResources* common_obj)
       : common(common_obj),
-        shimonoku_input(ShimonokuTyping), typing_complete(false) {
+        shimonoku_input(ShimonokuTyping, common->getConvertType()),
+        typing_complete(false) {
     }
 
   public:
@@ -262,6 +252,7 @@ struct ShimonokuPractice::pImpl {
 
       // rݏグ̊Jn
       common->gui->update();
+      // !!! XbhɂȂƁA`悪
       common->voice_->play(shimonoku_input.getCurrentWakaNo());
 
       typing_complete = false;
@@ -311,10 +302,8 @@ struct ShimonokuPractice::pImpl {
         shimonoku_input.removeInputComponents();
         typing_complete = true;
 
-        if (common->music) {
-          // ʉ̍Đ
-          common->sound_effect->play(Decide);
-        }
+        // ʉ̍Đ
+        common->playEffect(Decide);
       }
     }
 
@@ -467,7 +456,7 @@ struct ShimonokuPractice::pImpl {
   pImpl(void)
     : common(CommonResources::getObject()),
       scheduler(0, common) {
-    TypingState::getObject(common)->setPracticeNum(common->practice_num);
+    TypingState::getObject(common)->setPracticeNum(common->getPracticeNum());
   }
 
   void removeComponents(void) {
