@@ -150,10 +150,13 @@ void SoundEffectManager::updateVolume(size_t percent, int channel_id) {
   } else if (percent < 0) {
     percent = 0;
   }
-  Mix_Volume(channel_id, MIX_MAX_VOLUME * percent / 100);
-
-  // !!!
-  // !!! ʒB̂
+  if (channel_id != AllChannel) {
+    Mix_Volume(channel_id, MIX_MAX_VOLUME * percent / 100);
+  } else {
+    for (size_t i = 0; i < MixerInit::ChannelNum; ++i) {
+      Mix_Volume(i, MIX_MAX_VOLUME * percent / 100);
+    }
+  }
 }
 
 
