@@ -36,12 +36,11 @@ namespace beego {
       `ʒun_ƂāA`ItZbg`TCY`悷
     */
     virtual void draw(std::vector<SDL_Rect>& update_rects,
-                      const SDL_Rect* pos, const SDL_Rect* area,
-                      size_t ticks) = 0;
+                      const SDL_Rect* pos, const SDL_Rect* area) = 0;
     virtual size_t getWidth(void) = 0;
     virtual size_t getHeight(void) = 0;
     virtual void forceSetChanged(void) = 0;
-    virtual bool isChanged(void) = 0;
+    virtual bool isChanged(size_t ticks) = 0;
     virtual bool isTransparent(void) = 0;
   };
 };
