@@ -5,13 +5,26 @@
   \author Satofumi KAMIMURA
 
   $Id$
+
+  \todo t@C`FbNɂ FindFile Ȃǂ𗘗pׂ
 */
 
 #include "TtfResource.h"
 #include "TtfInit.h"
+#include "DetectOS.h"
+#ifdef MSC
+#include <windows.h>
+#include <direct.h>
+#include <io.h>
+#else
 #include <unistd.h>
+#endif
 #include <map>
 
+#ifdef MSC
+#define F_OK 06
+#endif
+
 using namespace beego;
 
 
@@ -56,7 +69,7 @@ TTF_Font* TtfResource::getResource(size_t size) {
   }
 
   // ݂ȂtHgTCY̏ꍇɁAtHg𐶐
-  TTF_Font* fp = TTF_OpenFont(pimpl->ttf_file, size);
+  TTF_Font* fp = TTF_OpenFont(pimpl->ttf_file, static_cast<int>(size));
   //fprintf(stderr, "%s: %p\n", pimpl->ttf_file, fp);
   if (fp == NULL) {
     // !!! error_message
