@@ -10,7 +10,9 @@
   $Id$
 */
 
+#include "TypingMode.h"
 #include <memory>
+#include <string>
 #include <vector>
 
 
@@ -39,32 +41,36 @@ public:
     \brief L[͏
   */
   typedef struct {
-    size_t ticks;               //!< ̓^C~O
+    int ticks;                  //!< ̓^C~O
     char ch;                    //!< ̓L[
   } KeyTiming;
 
-  /*!
-    \brief ^CsO
-  */
-  typedef enum {
-    ShimonokuTyping,
-    KimarijiTyping,
-  } TypingMode;
-
   /*!
     \brief ȁ
   */
   typedef struct {
-    size_t no;                   //!< a̔ԍ
+    int no;                      //!< a̔ԍ
     std::vector<KeyTiming> keys; //!< ̓L[
   } WakaTyping;
 
+  /*!
+    \brief L^ڍׂ̒`
+  */
+  typedef struct {
+    int miss_types;               //!< ^Cv~X̉ []
+    int delay_msec;               //!< ͊Jnx [msec]
+    int elapse_msec;              //!< oߎ [msec]
+  } ScoreData;
+
   /*!
     \brief Q[
   */
   typedef struct {
-    int rand_seed;                //!< _V[h
     TypingMode mode;              //!< ^CsO[h
+    std::string user_name;        //!< [U
+    time_t time;                  //!< L^ꂽ
+    int rand_seed;                //!< _V[h
+    ScoreData score;              //!< XRA
     std::vector<WakaTyping> waka; //!< ȁ
   } GameSettings;
 
@@ -96,8 +102,10 @@ public:
 
   /*!
     \brief o^e̕]
+
+    \param user_name [i] [U
   */
-  void evaluate(void);
+  void evaluate(const char* user_name);
 
   /*!
     \brief a̐̎擾
@@ -119,9 +127,19 @@ public:
   */
   size_t getMissTypes(void);
 
-  void to_s(void);
+  /*!
+    \brief Q[f[^Ԃ
+  */
+  GameSettings& getRecordData(void) const;
 
-  // !!! Ƃ肠A\
+  /*!
+    \brief Q[f[^̃GR[h
+  */
+  static std::string encodeGameData(const GameSettings& data);
+
+  /*!
+    \brief fobO\p
+  */
   void print(void);
 };
 
