@@ -22,7 +22,6 @@
 #include "InputHandler.h"
 #include "ButtonComponent.h"
 #include "MenuComponent.h"
-#include "SoundEffectManager.h"
 #include "SdlUtils.h"
 #include "Delay.h"
 
@@ -115,11 +114,8 @@ void UserMenu::run(void) {
     if (0 || selected >= 0) {
       //selected = 1;
 
-      // !!! Ƃ肠AŌ艹炷
-      // !!! Is\ȍڂ肵ƂɉςȂAύX
-      if (pimpl->common->music) {
-        pimpl->common->sound_effect->play(Decide);
-      }
+      // 艹炷
+      pimpl->common->playEffect(Decide);
 
       pimpl->removeComponents();
       if (selected == 0) {
