@@ -5,6 +5,10 @@
   \author Satofumi KAMIMURA
 
   $Id$
+
+  \todo J[\\
+  \todo ca̐ɕ\B͂Ƃ
+  \todo BS, s̉摜ׂ́Ah炵Ȃ\
 */
 
 #include "WakaDrawer.h"
@@ -148,9 +152,9 @@ struct WakaDrawer::pImpl {
     }
   }
 
-  void createRomanResource(const std::string& text) {
+  void createRomanResource(const std::vector<Uint16>& text) {
 
-    TextProperty roman_property(common->font, text.c_str(),
+    TextProperty roman_property(common->font, &text[0],
                                 RomanSize, Fore, Back, true);
     boost::shared_ptr<TextSurface>
       new_roman_surface(new TextSurface(roman_property));
@@ -343,8 +347,8 @@ void WakaDrawer::setWakaIndex(size_t index) {
 }
 
 
-void WakaDrawer::setInputSample(const std::vector<std::vector<Uint16> >&
-                                text, const std::string& roman_sample) {
+void WakaDrawer::setInputSample(const std::vector<std::vector<Uint16> >& text,
+                                const std::vector<Uint16>& roman_sample) {
 
   // T[tFX̍쐬
   pimpl->createRomanResource(roman_sample);
@@ -359,7 +363,7 @@ void WakaDrawer::setInputSample(const std::vector<std::vector<Uint16> >&
 
 void WakaDrawer::updateInputSample(const std::vector<std::vector<Uint16> >&
                                    text, size_t ku_index,
-                                   const std::string& roman_sample,
+                                   const std::vector<Uint16>& roman_sample,
                                    bool need_bs) {
   pimpl->draw_bs = need_bs;
 
