@@ -50,7 +50,7 @@ class WakaDrawer {
     \param roman_sample [i] [}͌
   */
   void setInputSample(const std::vector<std::vector<Uint16> >& text,
-                      const std::string& roman_sample);
+                      const std::vector<Uint16>& roman_sample);
 
   /*!
     \brief ͌̍XV
@@ -61,7 +61,8 @@ class WakaDrawer {
     \param need_bs [i] BackSpace L[𑣂ꍇ true
   */
   void updateInputSample(const std::vector<std::vector<Uint16> >& text,
-                         size_t ku_index, const std::string& roman_sample,
+                         size_t ku_index,
+                         const std::vector<Uint16>& roman_sample,
                          bool need_bs);
 
   /*!
